@@ -13,7 +13,7 @@
 ##############################################################################
 """Component Directives Tests
 
-$Id: test_directives.py 85829 2008-04-28 19:31:09Z lgs $
+$Id: test_directives.py 97663 2009-03-08 10:12:57Z nadako $
 """
 import re
 import unittest
@@ -24,9 +24,9 @@ from cStringIO import StringIO
 import zope.component
 from zope.interface import implements
 from zope.testing.doctestunit import DocTestSuite
-from zope.component.interfaces import IDefaultViewName
 from zope.component.interfaces import ComponentLookupError
 from zope.component.interface import queryInterface
+from zope.publisher.interfaces import IDefaultViewName
 
 from zope.configuration.xmlconfig import xmlconfig, XMLConfig
 from zope.configuration.exceptions import ConfigurationError
@@ -485,27 +485,6 @@ class Test(PlacelessSetup, unittest.TestCase):
             ))
         self.assertRaises(ValueError, xmlconfig, config, testing=1)
 
-    # BBB 2006/02/24, to be removed after 12 months
-    def testFactory(self):
-        showwarning = warnings.showwarning
-        warnings.showwarning = lambda *a, **k: None
-
-        self.assertRaises(ComponentLookupError, zope.component.createObject,
-                          'foo')
-
-        xmlconfig(StringIO(template % (
-            '''
-            <factory
-               id="foo.bar"
-               component="zope.app.component.tests.factory.f"
-               />
-            '''
-            )))
-
-        from factory import X
-        self.assertEqual(zope.component.createObject('foo.bar').__class__, X)
-
-        warnings.showwarning = showwarning
 
 class ParticipationStub(object):
 
